@@ -788,8 +788,13 @@ add_relation(AtkRelationSet *relations, AtkRelationType relation_type,
     if (relation) {
 	/* add new target accessible to relation */
 	GPtrArray* target_array = atk_relation_get_target (relation);
+	guint i;
 
-	g_ptr_array_remove (target_array, target_accessible);
+	/* first check if target occurs in array ... */
+	for (i = 0; i < target_array->len; i++)
+	    if (g_ptr_array_index(target_array, i) == target_accessible)
+		return;
+	g_object_ref(target_accessible);
 	g_ptr_array_add (target_array, target_accessible);
     } else {
 	/* the relation hasn't been created yet ... */
@@ -1246,7 +1251,18 @@ get_build_data(GType type)
     build_data = g_type_get_qdata(type, glade_build_data_id);
     
     if (build_data)
-	return build_data;
+	return build_data;  /* specific BuildData found */
+
+    /* gtkmm derives it's own types, but they aren't registed with glade_register_widget(),
+     * so look at the base type.
+     * If 3rd party custom widgets haven't used glade_register_widget() then this might mean that
+     * libglade mistakenly uses the base type's functions. */
+     build_data = g_type_get_qdata(g_type_parent(type), glade_build_data_id);
+
+    if (build_data)
+	return build_data;  /* specific BuildData found */
+
+    /* No specifc BuildData found - use something generic: */
     if (g_type_is_a(type, GTK_TYPE_CONTAINER))
 	return &container_build_data;
     else
@@ -1868,14 +1884,6 @@ glade_xml_handle_internal_child(GladeXML *self, GtkWidget *parent,
     while (parent_build_data == NULL && parent != NULL) {
 	parent_build_data = get_build_data(G_OBJECT_TYPE(parent));
 
-	if(parent_build_data->find_internal_child == NULL) {
-		/* gtkmm derives it's own types, but they aren't registed with glade_register_widget(),
-		 * so look at the base type.
-		 * If 3rd party custom widgets haven't used glade_register_widget() then this might mean that
-		 * libglade mistakenly uses the base type's functio. */
-		parent_build_data = get_build_data(g_type_parent(G_OBJECT_TYPE(parent)));
-	}
-
 	if (parent_build_data->find_internal_child != NULL)
 	    break;
 
